/* Layout */
import Layout from '@/layout'

// 机构认证审核路由
const clubAuditRoutes = [
  {
    path: 'club',
    component: () => import('@/views/admin/audit/club'),
    name: 'AuditClub',
    meta: { title: '机构认证', noCache: true }
  },
  {
    path: 'club/club-list',
    hidden: true,
    component: () => import('@/views/admin/audit/club/list'),
    name: 'AuditClubList',
    meta: { title: '机构认证审核', noCache: true }
  },
  {
    path: 'club/club-detail',
    hidden: true,
    component: () => import('@/views/admin/audit/club/review'),
    name: 'AuditClubDetail',
    meta: { title: '机构认证审核详情', noCache: true }
  },
  {
    path: 'club/device/list',
    hidden: true,
    component: () => import('@/views/admin/audit/club/device'),
    name: 'AuditClubDeviceList',
    meta: { title: '设备审核列表', noCache: true }
  },
  {
    path: 'club/device-detail',
    hidden: true,
    component: () => import('@/views/admin/audit/club/device/review'),
    name: 'AuditClubDeviceDetail',
    meta: { title: '设备审核详情', noCache: true }
  }
]

// 医师资料审核
const personnelAuditRoutes = [
  {
    path: 'personnel',
    component: () => import('@/views/admin/audit/personnel'),
    name: 'AuditPersonnel',
    meta: { title: '人员认证', noCache: true }
  },
  {
    path: 'personnel/operate/doctor-list',
    hidden: true,
    component: () => import('@/views/admin/audit/personnel/operate'),
    name: 'AuditOperateDoctorList',
    meta: { title: '操作师审核列表', noCache: true }
  },
  {
    path: 'personnel/operate/doctor-detail',
    hidden: true,
    component: () => import('@/views/admin/audit/personnel/operate/review'),
    name: 'AuditOperateDoctorDetail',
    meta: { title: '操作师审核详情', noCache: true }
  },
  {
    path: 'personnel/training/doctor-list',
    hidden: true,
    component: () => import('@/views/admin/audit/personnel/training'),
    name: 'AuditTrainingDoctorList',
    meta: { title: '培训师审核列表', noCache: true }
  },
  {
    path: 'personnel/training/doctor-detail',
    hidden: true,
    component: () => import('@/views/admin/audit/personnel/training/review'),
    name: 'AuditTrainingDoctorDetail',
    meta: { title: '培训师审核详情', noCache: true }
  }
]

// 资料库审核
const materialAuditRoutes = [
  {
    path: 'material',
    component: () => import('@/views/admin/audit/material'),
    name: 'AuditMaterial',
    meta: { title: '资料库', noCache: true }
  },
  {
    path: 'material/article-list',
    component: () => import('@/views/admin/audit/material/article'),
    name: 'AuditMaterialArticleList',
    hidden: true,
    meta: { title: '文章审核列表', noCache: true }
  },
  {
    path: 'material/article-detail',
    component: () => import('@/views/admin/audit/material/article/review'),
    name: 'AuditMaterialArticleDetail',
    hidden: true,
    meta: { title: '审核文章', noCache: true }
  },
  {
    path: 'material/image-list',
    component: () => import('@/views/admin/audit/material/image'),
    name: 'AuditMaterialImageList',
    hidden: true,
    meta: { title: '图片审核列表', noCache: true }
  },
  {
    path: 'material/image-detail',
    component: () => import('@/views/admin/audit/material/image/review'),
    name: 'AuditMaterialImageDetail',
    hidden: true,
    meta: { title: '审核图片', noCache: true }
  },
  {
    path: 'material/video-list',
    component: () => import('@/views/admin/audit/material/video'),
    name: 'AuditMaterialVideoList',
    hidden: true,
    meta: { title: '视频审核列表', noCache: true }
  },
  {
    path: 'material/file-list',
    component: () => import('@/views/admin/audit/material/file'),
    name: 'AuditMaterialFileList',
    hidden: true,
    meta: { title: '文件审核列表', noCache: true }
  },
  {
    path: 'material/package-list',
    component: () => import('@/views/admin/audit/material/package'),
    name: 'AuditMaterialPackageList',
    hidden: true,
    meta: { title: '资料包审核列表', noCache: true }
  }
]

// 设备管理审核
const deviceAuditRoutes = [
  {
    path: 'device/club-list',
    component: () => import('@/views/admin/audit/device'),
    name: 'AuditDevice',
    meta: { title: '设备管理', noCache: true }
  },
  {
    path: 'device/device-list',
    component: () => import('@/views/admin/audit/device/list'),
    name: 'AuditDeviceCateList',
    meta: { title: '设备管理审核', noCache: true }
  }
]

// 审核页面路由
const AuditRoutes = [
  {
    path: '/audit',
    component: Layout,
    alwaysShow: true,
    name: 'Audit',
    meta: { title: '审核管理', icon: 'el-icon-s-check', roles: ['admin'], noCache: true },
    children: [...clubAuditRoutes, ...personnelAuditRoutes, ...materialAuditRoutes, ...deviceAuditRoutes]
  }
]

export default AuditRoutes
